from setuptools import setup

setup(name='suhani_distribution',
      version='1.0',
      description='Gaussian distributions',
      packages=['suhani_distribution'],
      author = 'Suhani',
      author_mail = 'arorasuhani1511@gmail.com',
    zip_safe=False)
